import React, { useState, useEffect } from 'react';
import { motion } from 'framer-motion';
import { ChevronDown, ChevronUp } from 'lucide-react';
import InputLabel from '@/Components/FormComponents/InputLabel';
import Input from '@/Components/FormComponents/Input';
import { useForm } from '@inertiajs/react';
import InputTel from '@/Components/FormComponents/InputTel';
import Button from '@/Components/Buttons/Button';
import DeleteButton from '@/Components/Buttons/DeleteButton';
import toast, { Toaster } from 'react-hot-toast';
import TextArea from '@/Components/FormComponents/TextArea';

export default function Accordion({ lead, index, openIndex, handleToggle, handleRequest }) {
    const { data, setData, post: updatePost, processing: updateProcessing } = useForm({
        name: lead.name,
        number: lead.number || '',
        email: lead.email || '',
        comment: lead.comment || '',
        _method: 'PUT'
    });
    const { post: deletePost, processing: deleteProcessing } = useForm({ id: lead?.id, _method: 'DELETE' });

    // Estado para controlar modal delete
    const [isModalDeleteOpen, setIsModalDeleteOpen] = useState(false);
    const handleModalDelete = () => { setIsModalDeleteOpen(true) };
    const handleCloseModalDelete = () => { setIsModalDeleteOpen(false) };

    const contactUpdate = (e) => {
        e.preventDefault();
        handleRequest(updatePost, route('lead.update', lead?.id), 'Dados atualizados com sucesso!');
    };

    const contactDelete = (e) => {
        e.preventDefault();

        deletePost(route('lead.delete', lead?.id), {
            onSuccess: () => {
                toast.success('Contato deletado com sucesso!');

                handleCloseModalDelete();
            },
            onError: (errors) => {
                if (errors) {
                    toast.error(errors?.error || 'Ocorreu um erro inesperado.');
                }

                handleCloseModalDelete();
            }
        });
    };

    useEffect(() => {
        if (lead?.id) {
            setData({
                name: lead.name,
                number: lead.number || '',
                email: lead.email || '',
                comment: lead.comment || '',
                _method: 'PUT'
            });
        }
    }, [lead?.id]);

    return (
        <motion.div
            initial={{ opacity: 0 }}
            animate={{ opacity: 1 }}
            transition={{ duration: 0.5, delay: index * 0.04 }}
            className="rounded-2xl mb-2 overflow-hidden"
        >
            <Toaster />
            <button onClick={() => handleToggle(index)} className="flex justify-between items-center w-full p-4 text-left bg-bg-default focus:outline-none hover:bg-hover-default hover:bg-opacity-40">
                <div className="flex justify-start items-center">
                    {lead?.picture_url ? (
                        <img className='w-10 h-10 rounded-full me-3' src={lead?.picture_url} />
                    ) : (
                        <div className='flex justify-center items-center h-10 w-10 me-3 bg-primary rounded-full'>
                            <p className='text-text-white text-lg font-bold'>{lead?.letra}</p>
                        </div>
                    )}
                    <div>
                        <p className="text-[.8rem] font-bold text-text-primary">{lead?.name}</p>
                        {lead?.number
                            ? (<p className="text-[.7rem] font-normal text-text-primary">+{lead?.number}</p>)
                            : (<p className="text-[.7rem] font-normal text-text-primary">{lead?.email}</p>)
                        }
                    </div>
                </div>

                {openIndex === index ? <ChevronUp className='text-text-primary' /> : <ChevronDown className='text-text-primary' />}
            </button>

            <motion.div
                initial={{ height: 0, opacity: 0 }}
                animate={{ height: openIndex === index ? 'auto' : 0, opacity: openIndex === index ? 1 : 0 }}
                transition={{ duration: 0.3 }}
                className="overflow-hidden relative"
            >
                <form onSubmit={contactUpdate} className="p-4 text-gray-700 border-t border-border bg-bg-default">
                    <div className="grid lg:grid-cols-3 gap-2 mb-4">
                        <div>
                            <InputLabel htmlFor="name" value="Nome" required />
                            <Input
                                id="name"
                                type="text"
                                name="name"
                                value={data.name}
                                className="block w-full"
                                autoComplete="off"
                                required
                                placeholder="Nome"
                                onChange={(e) => setData("name", e.target.value)}
                            />
                        </div>

                        <div>
                            <InputLabel htmlFor="email" value="E-mail" />
                            <Input
                                id="email"
                                type="email"
                                name="email"
                                value={data.email}
                                className="block w-full"
                                autoComplete="off"
                                placeholder="E-mail"
                                onChange={(e) => setData("email", e.target.value)}
                            />
                        </div>

                        <div>
                            <InputLabel htmlFor="number" value="Telefone" />
                            <InputTel
                                country={'br'}
                                value={data.number}
                                onChange={(phone) => setData("number", phone)}
                                placeholder="Telefone"
                            />
                        </div>
                    </div>

                    <div className='mb-4'>
                        <InputLabel htmlFor="comment" value="Observação" />
                        <TextArea
                            id="comment"
                            name="comment"
                            value={data.comment}
                            rows="4"
                            autoComplete="off"
                            placeholder="Observação"
                            onChange={(e) => setData("comment", e.target.value)}
                        />
                    </div>

                    <div className='flex justify-between items-center'>
                        <Button className="mt-4" type="submit" disabled={updateProcessing}>Atualizar contato</Button>

                        <DeleteButton
                            onDelete={contactDelete}
                            disabled={deleteProcessing}
                            isOpen={isModalDeleteOpen}
                            openModal={handleModalDelete}
                            closeModal={handleCloseModalDelete}
                        />
                    </div>
                </form>
            </motion.div>
        </motion.div>
    );
}
